==> apache-eventmesh-1.9.0-source.tar.gz: apache-eventmesh-1.9.0-src/eventmesh-common/src/test/java/org/apache/eventmesh/common/utils/SystemUtilsTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.eventmesh.common.utils;

import org.junit.Assert;
import org.junit.Test;

public class SystemUtilsTest {

    @Test
    public void isLinuxPlatform() {
        if (null != SystemUtils.OS_NAME && SystemUtils.OS_NAME.toLowerCase().contains("linux")) {
            Assert.assertTrue(SystemUtils.isLinuxPlatform());
            Assert.assertFalse(SystemUtils.isWindowsPlatform());
        }
    }

    @Test
    public void isWindowsPlatform() {
        if (null != SystemUtils.OS_NAME && SystemUtils.OS_NAME.toLowerCase().contains("windows")) {
            Assert.assertFalse(SystemUtils.isLinuxPlatform());
            Assert.assertTrue(SystemUtils.isWindowsPlatform());
        }
    }

    @Test
    public void getProcessId() {
        Assert.assertNotEquals("-1", SystemUtils.getProcessId());
    }
}

==> apache-eventmesh-1.10.0-source.tar.gz: apache-eventmesh-1.10.0-src/eventmesh-common/src/test/java/org/apache/eventmesh/common/utils/SystemUtilsTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.eventmesh.common.utils;

import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;

public class SystemUtilsTest {

    @Test
    public void isLinuxPlatform() {
        if (null != SystemUtils.OS_NAME && SystemUtils.OS_NAME.toLowerCase().contains("linux")) {
            Assertions.assertTrue(SystemUtils.isLinuxPlatform());
            Assertions.assertFalse(SystemUtils.isWindowsPlatform());
        }
    }

    @Test
    public void isWindowsPlatform() {
        if (null != SystemUtils.OS_NAME && SystemUtils.OS_NAME.toLowerCase().contains("windows")) {
            Assertions.assertFalse(SystemUtils.isLinuxPlatform());
            Assertions.assertTrue(SystemUtils.isWindowsPlatform());
        }
    }

    @Test
    public void getProcessId() {
        Assertions.assertNotEquals("-1", SystemUtils.getProcessId());
    }
}
